# Browse torrent from good-old shell(bye-bye crappy ads:grin:)
[![Build Status](https://travis-ci.org/aksl337/torrent_scraper.svg?branch=master)](ttps://travis-ci.org/aksl337/torrent_scraper)



## Installation by [Pip](http://pip.readthedocs.org/en/stable/installing/)
For Python 3

```bash
$  pip install torrent-grab
```

or just run script with python
but make sure you have module requirements satisfied.

```bash
$  pip -r requirements.txt
```

## Usage

```bash
$ torrent-grab
```
